@@ -1,43 +1,17 @@
-from functools import lru_cache
-
 import regex
 import yarl
 
 from ...helper import uwu
+from .polling import ws_stimulation
 
 CONTENT_ID_REGEX = regex.compile(r"embed-6/([^?#&/.]+)")
 
-SID_REGEX = regex.compile(r'"sid":"(.+?)"')
-
-POLLING_PARAMETERS = {
-    "EIO": "4",
-    "transport": "polling",
-}
-
-
-@lru_cache()
-def ws_stimulation(session, *, url="https://ws1.rapid-cloud.ru/socket.io/"):
-    def poll(params={}, data=None):
-        soft = POLLING_PARAMETERS.copy()
-        soft.update(params)
-
-        if data is None:
-            return session.get(url, params=soft)
-        else:
-            return session.post(url, params=soft, data=data)
-
-    def get_sid(text: str) -> str:
-        return SID_REGEX.search(text).group(1)
-
-    polling_sid = get_sid(poll().text)
-
-    assert poll({"sid": polling_sid}, data="40").text == "ok"
-
-    return get_sid(poll({"sid": polling_sid}).text)
-
 
 def extract(session, url, **opts):
 
+    while ws_stimulation.session_sid is None:
+        pass
+
     content_id = CONTENT_ID_REGEX.search(url).group(1)
     recaptcha_response = uwu.bypass_recaptcha(session, url, opts["headers"])
 
@@ -56,21 +30,19 @@ def extract(session, url, **opts):
         _.get("file") for _ in sources.get("tracks") if _.get("kind") == "captions"
     ]
 
-    sid = ws_stimulation(session)
-
     def yielder():
         for _ in sources.get("sources"):
             yield {
                 "stream_url": _.get("file"),
                 "subtitle": subtitles,
-                "headers": {"SID": sid},
+                "headers": {"SID": ws_stimulation.session_sid},
             }
 
         for _ in sources.get("sourcesBackup"):
             yield {
                 "stream_url": _.get("file"),
                 "subtitle": subtitles,
-                "headers": {"SID": sid},
+                "headers": {"SID": ws_stimulation.session_sid},
             }
 
     return list(yielder())
