@@ -1,6 +1,7 @@
 from functools import partial
 
 import lxml.html as htmlparser
+import regex
 import yarl
 
 from ....config import ANIMEOUT
@@ -8,6 +9,8 @@ from ...helper import construct_site_based_regex, group_episodes, parse_from_con
 
 REGEX = construct_site_based_regex(ANIMEOUT, extra_regex=r"/([^?&/]+)")
 
+TITLES_REGEX = regex.compile(r'<h1 class="page-title">(.+?)</h1>')
+
 
 def animeout_stream_url(url: "yarl.URL") -> str:
     return "https://public.animeout.xyz/" + url.with_scheme("").human_repr().lstrip("/")
@@ -38,3 +41,7 @@ def fetcher(session, url, check, match):
     ):
         if check(episode):
             yield partial(list, content), episode
+
+
+def metadata_fetcher(session, url, match):
+    return {"titles": TITLES_REGEX.findall(session.get(url).text)}
